@@ -134,7 +134,7 @@ class Converter(object):
                     yield item
 
     def iter_from_json_file(self, json_file):
-        with io.open(json_file) as f:
+        with io.open(json_file, encoding='utf8') as f:
             data = json.load(f)
             if isinstance(data, Mapping):
                 yield self.load_from_dict(data)
@@ -165,6 +165,10 @@ class Converter(object):
             if r['from_name'] in self._output_tags:
                 v = deepcopy(r['value'])
                 v['type'] = self._schema[r['from_name']]['type']
+                if 'original_width' in r:
+                    v['original_width'] = r['original_width']
+                if 'original_height' in r:
+                    v['original_height'] = r['original_height']
                 outputs[r['from_name']].append(v)
         return {
             'input': inputs,
@@ -192,10 +196,10 @@ class Converter(object):
         output_file = os.path.join(output_dir, 'result.json')
         records = []
         for json_file in glob(os.path.join(input_dir, '*.json')):
-            with io.open(json_file) as f:
+            with io.open(json_file, encoding='utf8') as f:
                 records.append(json.load(f))
 
-        with io.open(output_file, mode='w') as fout:
+        with io.open(output_file, mode='w', encoding='utf8') as fout:
             json.dump(records, fout, indent=2, ensure_ascii=False)
 
     def convert_to_json_min(self, input_data, output_dir, is_dir=True):
@@ -210,7 +214,7 @@ class Converter(object):
                 record[name] = self._prettify(value)
             records.append(record)
 
-        with io.open(output_file, mode='w') as fout:
+        with io.open(output_file, mode='w', encoding='utf8') as fout:
             json.dump(records, fout, indent=2, ensure_ascii=False)
 
     def convert_to_csv(self, input_data, output_dir, is_dir=True, **kwargs):
@@ -233,7 +237,7 @@ class Converter(object):
         ensure_dir(output_dir)
         output_file = os.path.join(output_dir, 'result.conll')
         data_key = self._data_keys[0]
-        with io.open(output_file, 'w') as fout:
+        with io.open(output_file, 'w', encoding='utf8') as fout:
             fout.write('-DOCSTART- -X- O\n')
             item_iterator = self.iter_from_dir if is_dir else self.iter_from_json_file
 
@@ -268,21 +272,26 @@ class Converter(object):
             image_path = item['input'][data_key]
             if not os.path.exists(image_path):
                 try:
-                    image_path = download(image_path, output_image_dir)
+                    image_path, is_downloaded = download(image_path, output_image_dir)
+                    if is_downloaded:
+                        image_path = os.path.join(output_image_dir_rel, os.path.basename(image_path))
                 except:
                     logger.error('Unable to download {image_path}. The item {item} will be skipped'.format(
                         image_path=image_path, item=item
                     ), exc_info=True)
-                    continue
-            width, height = get_image_size(image_path)
+            bboxes = next(iter(item['output'].values()))
+            if len(bboxes) == 0:
+                logger.error('Empty bboxes.')
+                continue
+            width, height = bboxes[0]['original_width'], bboxes[0]['original_height']
             image_id = len(images)
             images.append({
                 'width': width,
                 'height': height,
                 'id': image_id,
-                'file_name': os.path.join(output_image_dir_rel, os.path.basename(image_path))
+                'file_name': image_path
             })
-            bboxes = next(iter(item['output'].values()))
+
             for bbox in bboxes:
                 category_name = bbox['rectanglelabels'][0]
                 if category_name not in category_name_to_id:
@@ -309,7 +318,7 @@ class Converter(object):
                     'area': w * h
                 })
 
-        with io.open(output_file, mode='w') as fout:
+        with io.open(output_file, mode='w', encoding='utf8') as fout:
             json.dump({
                 'images': images,
                 'categories': categories,
@@ -350,7 +359,9 @@ class Converter(object):
                 os.makedirs(annotations_dir)
             if not os.path.exists(image_path):
                 try:
-                    image_path = download(image_path, output_image_dir)
+                    image_path, is_downloaded = download(image_path, output_image_dir)
+                    if not is_downloaded:
+                        output_image_dir_rel = os.path.dirname(image_path)
                 except:
                     logger.error('Unable to download {image_path}. The item {item} will be skipped'.format(
                         image_path=image_path, item=item), exc_info=True)
@@ -403,5 +414,5 @@ class Converter(object):
                 object_node.appendChild(bndbox_node)
                 root_node.appendChild(object_node)
 
-            with io.open(xml_filepath, mode='w') as fout:
+            with io.open(xml_filepath, mode='w', encoding='utf8') as fout:
                 doc.writexml(fout, addindent='' * 4, newl='\n', encoding='utf-8')
